@@ -122,31 +122,74 @@ gnome_settings_bus_get_shell_proxy (void)
         return shell_proxy;
 }
 
-static gboolean
-is_wayland_session (void)
+char *
+gnome_settings_get_chassis_type (void)
+{
+        char *ret = NULL;
+        GError *error = NULL;
+        GVariant *inner;
+        GVariant *variant = NULL;
+        GDBusConnection *connection;
+
+        connection = g_bus_get_sync (G_BUS_TYPE_SYSTEM,
+                                     NULL,
+                                     &error);
+        if (connection == NULL) {
+                g_warning ("system bus not available: %s", error->message);
+                g_error_free (error);
+                goto out;
+        }
+
+        variant = g_dbus_connection_call_sync (connection,
+                                               "org.freedesktop.hostname1",
+                                               "/org/freedesktop/hostname1",
+                                               "org.freedesktop.DBus.Properties",
+                                               "Get",
+                                               g_variant_new ("(ss)",
+                                                              "org.freedesktop.hostname1",
+                                                              "Chassis"),
+                                               NULL,
+                                               G_DBUS_CALL_FLAGS_NONE,
+                                               -1,
+                                               NULL,
+                                               &error);
+        if (variant == NULL) {
+                g_debug ("Failed to get property '%s': %s", "Chassis", error->message);
+                g_error_free (error);
+                goto out;
+        }
+
+        g_variant_get (variant, "(v)", &inner);
+        ret = g_variant_dup_string (inner, NULL);
+        g_variant_unref (inner);
+out:
+        g_clear_object (&connection);
+        g_clear_pointer (&variant, g_variant_unref);
+        return ret;
+}
+
+static gpointer
+is_wayland_session (gpointer user_data)
 {
 #if HAVE_WAYLAND
         struct wl_display *display;
 
         display = wl_display_connect (NULL);
         if (!display)
-                return FALSE;
+                return GUINT_TO_POINTER(FALSE);
         wl_display_disconnect (display);
-        return TRUE;
+        return GUINT_TO_POINTER(TRUE);
 #else
-        return FALSE;
+        return GUINT_TO_POINTER(FALSE);
 #endif
 }
 
 gboolean
 gnome_settings_is_wayland (void)
 {
-        static gboolean checked = FALSE;
-        static gboolean wayland = FALSE;
+        static GOnce wayland_once = G_ONCE_INIT;
 
-        if (!checked) {
-                wayland = is_wayland_session ();
-                checked = TRUE;
-        }
-        return wayland;
+        g_once (&wayland_once, is_wayland_session, NULL);
+
+        return GPOINTER_TO_UINT(wayland_once.retval);
 }
